@@ -1,9 +1,8 @@
-import connectors.PostgresConnector as PostgresConnector
+from request import *
+from PostgresConnector import *
 from error_handlers import *
 from data import *
-from request import *
 import sys
-
 from data_formatter import defaultDataFormatter
 
 # todo add exec raw query
@@ -17,7 +16,7 @@ class DB:
     def __init__(self, connector_type, *conn_args, format=None, **conn_kwargs):
         self.meta = dict()
         if connector_type == 'postgres':
-            self.meta['connector'] = PostgresConnector.PostgresConnector(*conn_args, **conn_kwargs)
+            self.meta['connector'] = PostgresConnector(*conn_args, **conn_kwargs)
         else:
             raise Exception('unknown connector type')
 
